==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebPivotKeysDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotKeysDescription } from "./WebPivotKeysDescription";
/**
 * @hidden
 */
var WebPivotKeysDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPivotKeysDescriptionMetadata, _super);
    function WebPivotKeysDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotKeysDescriptionMetadata.b = function (a) {
        if (WebPivotKeysDescriptionMetadata.a == null) {
            WebPivotKeysDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotKeysDescriptionMetadata.c(WebPivotKeysDescriptionMetadata.a);
        }
        if (a.k(WebPivotKeysDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPivotKeysDescriptionMetadata.a);
    };
    WebPivotKeysDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotKeys");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Children", "String");
        a.item("Records", "String");
        a.item("Aggregations", "String");
        a.item("Level", "String");
        a.item("ColumnDimensionSeparator", "String");
        a.item("RowDimensionSeparator", "String");
    };
    WebPivotKeysDescriptionMetadata.d = function (a) {
        WebPivotKeysDescriptionMetadata.b(a);
        a.ac("WebPivotKeys", function () { return new WebPivotKeysDescription(); });
        a.ab("WebPivotKeys", WebPivotKeysDescriptionMetadata.a);
    };
    WebPivotKeysDescriptionMetadata.$t = markType(WebPivotKeysDescriptionMetadata, 'WebPivotKeysDescriptionMetadata');
    WebPivotKeysDescriptionMetadata.a = null;
    return WebPivotKeysDescriptionMetadata;
}(Base));
export { WebPivotKeysDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebPivotKeysDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotKeysDescription } from "./WebPivotKeysDescription";
/**
 * @hidden
 */
var WebPivotKeysDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotKeysDescriptionMetadata, _super);
    function WebPivotKeysDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotKeysDescriptionMetadata.b = function (a) {
        if (WebPivotKeysDescriptionMetadata.a == null) {
            WebPivotKeysDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotKeysDescriptionMetadata.c(WebPivotKeysDescriptionMetadata.a);
        }
        if (a.k(WebPivotKeysDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebPivotKeysDescriptionMetadata.a);
    };
    WebPivotKeysDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotKeys");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Children", "String");
        a.item("Records", "String");
        a.item("Aggregations", "String");
        a.item("Level", "String");
        a.item("ColumnDimensionSeparator", "String");
        a.item("RowDimensionSeparator", "String");
    };
    WebPivotKeysDescriptionMetadata.d = function (a) {
        WebPivotKeysDescriptionMetadata.b(a);
        a.ae("WebPivotKeys", function () { return new WebPivotKeysDescription(); });
        a.ad("WebPivotKeys", WebPivotKeysDescriptionMetadata.a);
    };
    WebPivotKeysDescriptionMetadata.$t = markType(WebPivotKeysDescriptionMetadata, 'WebPivotKeysDescriptionMetadata');
    WebPivotKeysDescriptionMetadata.a = null;
    return WebPivotKeysDescriptionMetadata;
}(Base));
export { WebPivotKeysDescriptionMetadata };
